@@ -47,6 +47,7 @@ class TestImageTransform:
             transformed = im.transform(
                 im.size, Image.Transform.AFFINE, [1, 0, 0, 0, 1, 0]
             )
+            assert im.palette is not None
             assert im.palette.palette == transformed.palette.palette
 
     def test_extent(self) -> None:
@@ -192,8 +193,9 @@ class TestImageTransform:
 
         im = op(im, (40, 10))
 
-        colors = sorted(im.getcolors())
-        assert colors == sorted(
+        colors = im.getcolors()
+        assert colors is not None
+        assert sorted(colors) == sorted(
             (
                 (20 * 10, opaque),
                 (20 * 10, transparent),
